@@ -1,4 +1,6 @@
+from .api_client import APIException
 from .auth_api import Authentication
 from .virt_api import Virtualization
 from .storage_api import Storage
 from .protection_api import Protection
+from .jobs_api import Jobs
